@@ -9,8 +9,8 @@
     size <- if (v > m) m^2/(v - m) else 100
 	size = trunc(size)
 	if(size == 0) size =1
-    densfun <- function(par) -sum(dnbinom((maxshift:Mtmp)-shift,size=par[1],mu=par[2],log=TRUE)*eta[maxshift:Mtmp])    
-    -nlm(densfun,c(size,m))$minimum
+    densfun <- function(par) - sum(dnbinom((maxshift:Mtmp)-shift,size=par[1],mu=par[2],log=TRUE)*eta[maxshift:Mtmp])    
+    out<- suppressWarnings(- nlm(densfun,c(size,m))$minimum)
   }
   shift = which.max(sapply(1:maxshift,fun1))
   m <- weighted.mean((maxshift:Mtmp)-shift,eta[maxshift:Mtmp])
@@ -21,6 +21,6 @@
   if(size == 0) size =1
   size <- if (v > m) m^2/(v - m) else 100
   densfun <- function(par) -sum(dnbinom((maxshift:Mtmp)-shift,size=par[1],mu=par[2],log=TRUE)*eta[maxshift:Mtmp])        
-  tmp = nlm(densfun,c(size,m))$estimate
+  suppressWarnings(tmp <- nlm(densfun,c(size,m))$estimate)
   c(shift = shift,size=max(1,trunc(tmp[1])),mu=tmp[2],prob=max(1,trunc(tmp[1]))/(sum(tmp)))
 }
